#!/usr/bin/env python

import matplotlib as mpl
import matplotlib.pyplot as plt
from numpy import *
from pylab import *
from scipy.io import loadmat
import matplotlib.cm as cm
# tick
from matplotlib.ticker import MultipleLocator,MaxNLocator
from matplotlib.ticker import AutoMinorLocator,NullLocator
import os
if not os.path.exists("Figs"): os.mkdir("Figs")


############## Setting ##########################

output_path='./Figs/mx_sigsdn_2016.eps'

#################################################
# set to be square
figure = plt.figure(figsize=(7.5, 7.5));

XYlimit=([ 1.0,1e4,1e-7,1e-1]);
#X_To_Y=abs(XYlimit[1]-XYlimit[0])/abs(XYlimit[3]-XYlimit[2])
#axes = figure.add_subplot(1,1,1,aspect=X_To_Y);
axes = figure.add_subplot(1,1,1);

axes.xaxis.set_major_locator(MaxNLocator(6));
axes.xaxis.set_minor_locator(AutoMinorLocator());
axes.yaxis.set_major_locator(MaxNLocator(5));
axes.yaxis.set_minor_locator(AutoMinorLocator());

plt.box('on'); 
plt.hold('on');

for label_i in axes.get_xticklabels(): 
    label_i.set_fontsize(20) 

for label_i in axes.get_yticklabels(): 
    label_i.set_fontsize(17) 


plt.tick_params(which='both', width=2)
plt.tick_params(which='major', length=8)
plt.tick_params(which='minor', length=4, color='k')


axes.set_xscale('log');
axes.set_yscale('log');


plt.axis(XYlimit); # set the range (x,y)



#rc('text', usetex=True)
#rc('font', **{'family':'serif','serif':['mathpazo']})

plt.xlabel(r'$m_\chi$ (GeV)',fontsize=25); 
plt.ylabel(r'$\sigma_n^{\rm{SD}}$ (pb)',fontsize=25);
axes.xaxis.set_label_coords(0.5,-0.05)
axes.yaxis.set_label_coords(-0.08, 0.45)

plt.suptitle('LikeDM (2016)',fontsize=15, x = 0.8, y = 0.93) #x=<0,1>, y=<0,1>

#... Of course you can modify the below line manually ...
#plt.text(450.0,2e-7, r'Profile Likelihood',fontsize=20)
#plt.text(450.0,1e-7, r'CP-conserving',fontsize=20)



tmp = loadtxt('./LUX/2016/LUX2016_sigsdn.txt');
mx = tmp[:,0];
sigsip = tmp[:,1]*1e36;
plt.plot(mx,sigsip,'-r',lw=3,label='LUX (2016)');


tmp = loadtxt('./DD_future/sigsdn_X1T.txt');
mx = tmp[:,0];
sigsip = tmp[:,1];
plt.plot(mx,sigsip,'--',color='k',lw=2,label='XENON1T (projected)');

tmp = loadtxt('./DD_future/sigsdn_LZ.txt');
mx = tmp[:,0];
sigsip = tmp[:,1];
plt.plot(mx,sigsip,'-.',color='b',lw=2,label='LZ (projected)')






'''
tmp = loadtxt('./DD_future/neutrino_bound.txt');
#mx = tmp[:,0];
#sigsip = tmp[:,1];
#plt.plot(mx,sigsip,'--',color='orange',lw=5,label=r'$\nu$ coherent scattering');

x=[]
y=[]

for i in xrange(len(tmp[:,0])):
   x.append(float(tmp[i,0]))
   y.append(float(tmp[i,1]))
x.append(float(tmp[-1,0]))
y.append(1e-20);
x.append(float(tmp[0,0]))
y.append(1e-20);
x.append(float(tmp[0,0]))
y.append(float(tmp[0,1]))

PC = axes.fill_between(x,y, color='y')

bbox_props = dict(boxstyle="round", fc="w", ec="k", alpha=0.9)
axes.text(3.0,3e-12, r'$\nu$ coherent scattering', ha="center", va="center", size=20, color='k', rotation=90,
        bbox=bbox_props)
'''


#plt.plot([1e30,1e30],[2e30,2e30],'-', color='b',lw=1.0,label=r'95% C.L. of $\Lambda/m_\chi>10$');
#plt.plot([1e30,1e30],[2e30,2e30],'s', ms=20, mfc='gray', mec='gray',label=r'95% C.L. of $2<\Lambda/m_\chi<10$');


legend(loc='upper right', prop={'size':16}, numpoints=1, fancybox=True)

#plt.grid(True) #making the grid
plt.hold('off');
#mpl.rcParams['ps.papersize']='b6' #set(gcf, 'PaperUnits','centimeters'); set(gcf, 'PaperSize',[16.5 16.5]);

print 'Saving figure in', output_path
ps = plt.savefig(output_path);
#plt.savefig('test.png', bbox_inches='tight', dpi=200);
